<?php
/* $Id: slovak-windows-1250.inc.php,v 2.150 2006/08/09 12:55:40 lem9 Exp $ */

/* By: lubos klokner <erkac@vault-tec.sk> */
/* and Ivan Kuriscak <shylauda69@yahoo.com>
   and Tomas Tatransky <tomas.tatransky@centrum.sk> */

$charset = 'windows-1250';
$text_dir = 'ltr';
$number_thousands_separator = ' ';
$number_decimal_separator = ',';
// shortcuts for Byte, Kilo, Mega, Giga, Tera, Peta, Exa
$byteUnits = array('Bajtov', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB');

$day_of_week = array('Ne', 'Po', 't', 'St', 't', 'Pi', 'So');
$month = array('Jan', 'Feb', 'Mar', 'Apr', 'Mj', 'Jn', 'Jl', 'Aug', 'Sep', 'Okt', 'Nov', 'Dec');
// See http://www.php.net/manual/en/function.strftime.php to define the
// variable below
$datefmt = '%d.%B, %Y - %H:%M';
$timespanfmt = '%s dn, %s hodn, %s mint a %s seknd';

$strAbortedClients = 'Preruen';
$strAbsolutePathToDocSqlDir = 'Prosm zadajte absoltnu cestu k adresru docSQL na serveri.';
$strAccessDeniedCreateConfig = 'Pravdepodobn prina je, e neexistuje konfiguran sbor. Na jeho vytvorenie mete poui %1$skonfiguran skript%2$s.';
$strAccessDeniedExplanation = 'phpMyAdmin sa poksil pripoji k MySQL serveru ale ten spojenie odmietol. Skontrolujte prosm meno serveru, pouvatesk meno a heslo v sbore config.inc.php a s tm, ktor ste dostali o administrtora MySQL servera.';
$strAccessDenied = 'Prstup zamietnut';
$strAction = 'Akcia';
$strAddAutoIncrement = 'Prida hodnotu AUTO_INCREMENT';
$strAddClause = 'Prida %s';
$strAddConstraints = 'Prida obmedzenia';
$strAddDeleteColumn = 'Prida/Odobra polia stpcov';
$strAddDeleteRow = 'Prida/Odobra kritria riadku';
$strAddedColumnComment = 'Pridan komentr k stpcu';
$strAddedColumnRelation = 'Pridan vzah pre stpec';
$strAddFields = 'Prida %s poloiek';
$strAddHeaderComment = 'Prida vlastn komentr do hlaviky (\\n oddeuje riadky)';
$strAddIntoComments = 'Prida do komentrov';
$strAddNewField = 'Prida nov pole';
$strAddPrivilegesOnDb = 'Prida oprvnenia pre nasledujcu databzu';
$strAddPrivilegesOnTbl = 'Prida oprvnenia pre nasledujcu tabuku';
$strAddSearchConditions = 'Prida vyhadvacie parametre (obsah dopytu po "where" prkaze):';
$strAddToIndex = 'Prida do indexu &nbsp;%s&nbsp;stpec';
$strAddUserMessage = 'Pouvate bol pridan.';
$strAddUser = 'Prida novho pouvatea';
$strAdministration = 'Administrcia';
$strAffectedRows = ' Ovplyvnen riadky: ';
$strAfterInsertBack = 'Sp';
$strAfterInsertNewInsert = 'Vloi nov zznam';
$strAfterInsertNext = 'Upravi nasledujci riadok';
$strAfterInsertSame = 'Sp na tto strnku';
$strAfter = 'Po %s';
$strAllowInterrupt = 'Povoli preruenie importu v prpade, e sa bli asov limit behu skriptu. Tmto spsobom sa mu importova aj vek sbory, ale me to zrove spsobi problmy s transakciami.';
$strAllTableSameWidth = 'zobrazi vetky tabuky s rovnakou rkou?';
$strAll = 'Vetko';
$strAlterOrderBy = 'Zmeni poradie tabuky poda';
$strAnalyzeTable = 'Analyzova tabuku';
$strAnd = 'a';
$strAndThen = 'a potom';
$strAnIndex = 'Bol pridan index pre %s';
$strAny = 'Akkovek';
$strAnyHost = 'Akkovek hostite';
$strAnyUser = 'Akkovek pouvate';
$strApproximateCount = 'Me by nepresn. Pozri FAQ 3.11';
$strAPrimaryKey = 'Bol pridan primrny k pre %s';
$strArabic = 'Arabtina';
$strArmenian = 'Armntina';
$strAscending = 'Vzostupne';
$strAtBeginningOfTable = 'Na zaiatku tabuky';
$strAtEndOfTable = 'Na konci tabuky';
$strAttr = 'Atribty';
$strAutodetect = 'Automaticky zisti';
$strAutomaticLayout = 'Automatick rozvrhnutie';

$strBack = 'Sp';
$strBaltic = 'Baltick';
$strBeginCut = 'ZAIATOK VSEKU';
$strBeginRaw = 'ZAIATOK TOKU';
$strBinary = 'Binrny';
$strBinaryDoNotEdit = 'Binrny - neupravujte ';
$strBinaryLog = 'Binrny log';
$strBinLogEventType = 'Typ udalosti';
$strBinLogInfo = 'Informcia';
$strBinLogName = 'Nzov logu';
$strBinLogOriginalPosition = 'Pvodn pozcia';
$strBinLogPosition = 'Pozcia';
$strBinLogServerId = 'ID servra';
$strBookmarkAllUsers = 'Dovoli pouva tto poloku vetkm pouvateom';
$strBookmarkCreated = 'Prkaz %s bol zaraden medzi obben';
$strBookmarkDeleted = 'Zznam z obbench bol zmazan.';
$strBookmarkLabel = 'Nzov';
$strBookmarkQuery = 'Obben SQL dopyt';
$strBookmarkReplace = 'Prepsa existujci prkaz s rovnakm menom';
$strBookmarkThis = 'Prida tento SQL dopyt do obbench';
$strBookmarkView = 'Iba prezrie';
$strBrowseDistinctValues = 'Prechdza in hodnoty';
$strBrowseForeignValues = 'Prejs hodnoty cudzch kov';
$strBrowse = 'Prechdza';
$strBufferPoolActivity = 'Aktivita Vyrovnvacej Pamte';
$strBufferPoolUsage = 'Vyuitie Vyrovnvacej Pamte';
$strBufferPool = 'Vyrovnvacia Pam';
$strBufferReadMissesInPercent = 'Vpadkov pri tan v %';
$strBufferReadMisses = 'Vpadkov pri tan';
$strBufferWriteWaits = 'akan na zpis';
$strBufferWriteWaitsInPercent = 'akan na zpis v %';
$strBulgarian = 'Bulharsky';
$strBusyPages = 'Spracovvanch strnok';
$strBzError = 'nepodarilo sa skomprimova vstup z dvodu chybnho rozrenia pre kompresiu Bz2 v tejto verzii php. Doporuuje sa nastavi <code>$cfg[\'BZipDump\']</code> v konfigurcii phpMyAdmin na <code>FALSE</code>. Ak si elte pouva kompresiu Bz2 mali by ste naintalova noviu verziu php. Viac informci zskate z popisu chyby: %s.';
$strBzip = '"bzipped"';

$strCalendar = 'Kalendr';
$strCanNotLoadExportPlugins = 'Nepodarilo sa nata exportn pluginy, skontrolujte prosm vau intalciu!';
$strCanNotLoadImportPlugins = 'Nebolo mon nata importovacie pluginy, skontrolujte prosm vau intalciu!';
$strCannotLogin = 'Ned sa prihlsi k MySQL serveru';
$strCantLoad = 'ned sa nahra rozrenie %s,<br />prosm skontrolujte konfigurciu PHP';
$strCantLoadRecodeIconv = 'Nie je mon nahra rozrenie iconv alebo recode potrebn pre prevod znakovch sad. Upravte nastavenie php tak aby umoovalo poui tieto rozrenia alebo vypnite tto vlastnos v konfigurcii phpMyAdmina.';
$strCantRenameIdxToPrimary = 'Nie je mon premenova index na PRIMARY!';
$strCantUseRecodeIconv = 'Nie je mon poui funkcie iconv, libiconv a recode_string aj napriek tomu, e rozrenia s nahran. Skontrolujte prosm nastavenie PHP.';
$strCardinality = 'Mohutnos';
$strCaseInsensitive = 'nerozliova vek a mal psmen';
$strCaseSensitive = 'rozliova vek a mal psmen';
$strCentralEuropean = 'Stredn Eurpa';
$strChangeCopyModeCopy = '... zachova pvodnho pouvatea.';
$strChangeCopyModeDeleteAndReload = ' ... zmaza pvodnho pouvatea z tabuliek pouvateov a potom znovunata oprvnenia.';
$strChangeCopyModeJustDelete = ' ... zmaza pvodnho pouvatea z tabuliek pouvateov.';
$strChangeCopyModeRevoke = ' ... odobra vetky oprvnenia pvodnmu pouvateovi a nsledne ho zmaza.';
$strChangeCopyMode = 'Vytvori pouvatea s rovnakmi prvami a...';
$strChangeCopyUser = 'Zmeni informcie o pouvateovi / Koprova pouvatea';
$strChangeDisplay = 'Zvolte, ktor pole zobrazi';
$strChangePassword = 'Zmeni heslo';
$strChange = 'Zmeni';
$strCharsetOfFile = 'Znakov sada sboru:';
$strCharsetsAndCollations = 'Znakov sady a Zotriedenia';
$strCharsets = 'Znakov sady';
$strCharset = 'Znakov sada';
$strCheckAll = 'Oznai vetko';
$strCheckOverhead = 'Zvoli neoptimlne';
$strCheckPrivsLong = 'Skontrolova oprvnenia pre databzu &quot;%s&quot;.';
$strCheckPrivs = 'Skontrolova oprvnenia';
$strCheckTable = 'Skontrolova tabuku';
$strChoosePage = 'Prosm zvolte si Strnku, ktor chcete upravi';
$strColComFeat = 'Zobrazova komentre stpcov';
$strCollation = 'Zotriedenie';
$strColumnNames = 'Nzvy stpcov';
$strColumnPrivileges = 'Oprvnenia pre jednotliv stpce';
$strCommand = 'Prkaz';
$strCommentsForTable = 'KOMENTRE PRE TABUKU';
$strComments = 'Komentre';
$strCompatibleHashing = 'Kompatibiln s&nbsp;MySQL&nbsp;4.0';
$strCompleteInserts = 'pln vloenie';
$strCompression = 'Kompresia';
$strCompressionWillBeDetected = 'Kompresia importovanho sboru bude rozpoznan automaticky. Podporovan: %s';
$strConfigDefaultFileError = 'Nepodarilo sa nata prednastaven konfigurciu zo sboru: "%1$s"';
$strConfigFileError = 'phpMyAdmin nebol schopn nata konfiguran sbor!<br />Tento problm sa zvyajne vyskytne ak sbor obsahuje chybu alebo ho php nemohlo njs.<br />Zavolajte browserom tento sbor priamo pouitm nasledujceho odkazu na zskanie chybovch hlok, ktor s nm spsoben. Vinou sa jedn o chbajcu vodzovku alebo bodkoiarku.<br />Ak dostanete iba przdnu strnku, vetko je v poriadku.';
$strConfigureTableCoord = 'Prosm skonfigurujte koordinty pre tabuku %s';
$strConnectionError = 'Nepodarilo sa pripoji: chybn nastavenia.';
$strConnections = 'Spojenia';
$strConstraintsForDumped = 'Obmedzenie pre exportovan tabuky';
$strConstraintsForTable = 'Obmedzenie pre tabuku';
$strCookiesRequired = 'Cookies musia by povolen, pokia chcete pokraova.';
$strCopyDatabaseOK = 'Databza %s bola skoprovan na %s';
$strCopy = 'Koprova';
$strCopyTableOK = 'Tabuka %s bola skorrovan do %s.';
$strCopyTableSameNames = 'Ned sa skoprova tabuka sama do seba!';
$strCopyTable = 'Skoprova tabuku do (databza<b>.</b>tabuka):';
$strCouldNotKill = 'Neporadilo za zabi vlkno %s. Jeho beh bol pravdepodobne u ukonen.';
$strCreateDatabaseBeforeCopying = 'Vytvori databzu (CREATE DATABASE) pred koprovanm';
$strCreateIndexTopic = 'Vytvori nov index';
$strCreateIndex = 'Vytvori index na&nbsp;%s&nbsp;stpcoch';
$strCreateNewDatabase = 'Vytvori nov databzu';
$strCreateNewTable = 'Vytvori nov tabuku v databze %s';
$strCreatePage = 'Vytvori nov Strnku';
$strCreatePdfFeat = 'Vytvranie PDF';
$strCreateUserDatabase = 'Databza pre pouvatea';
$strCreateUserDatabaseName = 'Vytvori databzu s rovnakm menom a prideli vetky oprvnenia';
$strCreateUserDatabaseNone = 'iadna';
$strCreateUserDatabaseWildcard = 'Prideli vetky oprvnenia pomocou masky (pouvate_%)';
$strCreate = 'Vytvori';
$strCreationDates = 'Dtum vytvorenia, poslednej zmeny a kontroly';
$strCriteria = 'Kritria';
$strCroatian = 'Chorvtsky';
$strCSV = 'CSV';
$strCSVImportOptions = 'Monosti CSV';
$strCSVOptions = 'Nastavenia pre CSV';
$strCyrillic = 'Cyrilika';
$strCzech = 'esky';
$strCzechSlovak = 'etina/Slovenina';

$strDanish = 'Dnsky';
$strDatabase = 'Databza';
$strDatabaseEmpty = 'Meno databzy je przdne!';
$strDatabaseExportOptions = 'Nastavenia exportu databz';
$strDatabaseHasBeenDropped = 'Databza %s bola zmazan.';
$strDatabaseNoTable = 'Tto databza neobsahuje iadne tabuky!';
$strDatabases = 'Databzy';
$strDatabasesDropped = 'spene zruench databz: %s.';
$strDatabasesStatsDisable = 'Skry tatistiky';
$strDatabasesStatsEnable = 'Zobrazi tatistiky';
$strDatabasesStatsHeavyTraffic = 'Poznmka: Aktivovanie tatistk databzy me spsobi znan zvenie sieovej prevdzky medzi databzou a web serverom.';
$strDatabasesStats = 'tatistiky databzy';
$strData = 'Dta';
$strDataDict = 'Dtov slovnk';
$strDataOnly = 'Iba dta';
$strDataPages = 'Strnky obsahujce dta';
$strDBComment = 'Komentr k databze: ';
$strDBCopy = 'Skoprova databzu na';
$strDBGContextID = 'Kontext ID';
$strDBGContext = 'Kontext';
$strDBGHits = 'Zsahov';
$strDBGLine = 'Riadok';
$strDBGMaxTimeMs = 'Max. as, ms';
$strDBGMinTimeMs = 'Min as, ms';
$strDBGModule = 'Modul';
$strDBGTimePerHitMs = 'as/Zsah, ms';
$strDBGTotalTimeMs = 'Celkov as, ms';
$strDbPrivileges = 'Oprvnenia pre jednotliv databzy';
$strDBRename = 'Premenova databzu na';
$strDbSpecific = 'zvisl na databze';
$strDefaultEngine = 'Na tomto MySQL servri je prednastavenm lonm systmom %s.';
$strDefault = 'Predvolen';
$strDefaultValueHelp = 'Pre predvolen hodnoty, prosm zadajte iba jednu hodnotu bez vodzoviek alebo uvdzacch znakov, napr.: a';
$strDefragment = 'Defragmentova tabuku';
$strDelayedInserts = 'Poui oneskoren vloenia';
$strDeleteAndFlushDescr = 'Toto je najistejie rieenie, ale znovunatanie prv me chvu trva.';
$strDeleteAndFlush = 'Odstrni pouvateov a znovunata prva.';
$strDeleted = 'Riadok bol zmazan';
$strDeletedRows = 'Zmazan riadky:';
$strDeleteNoUsersSelected = 'Na odstrnenie neboli vybran iadni pouvatelia!';
$strDelete = 'Zmaza';
$strDeleting = 'Odstrauje sa %s';
$strDelimiter = 'Oddeova';
$strDelOld = 'Aktulna strnka sa odkazuje na tabuky, ktor u neexistuj, elte si odstrni tieto odkazy?';
$strDescending = 'Zostupne';
$strDescription = 'Popis';
$strDictionary = 'slovnk';
$strDirtyPages = 'Zmenench strnok';
$strDisabled = 'Vypnut';
$strDisableForeignChecks = 'Vypn kontrolu cudzch kov';
$strDisplayFeat = 'Zobrazi vlastnosti';
$strDisplayOrder = 'Zobrazi zoraden:';
$strDisplayPDF = 'Zobrazi schmu PDF';
$strDoAQuery = 'Vykona "dopyt poda prkladu" (nahradzujci znak: "%")';
$strDocu = 'Dokumentcia';
$strDoYouReally = 'Skutone chcete vykona prkaz ';
$strDropDatabaseStrongWarning = 'Chystte sa ZRUI cel databzu!';
$strDrop = 'Odstrni';
$strDropUsersDb = 'Odstrni databzy s rovnakm menom ako maj pouvatelia.';
$strDumpingData = 'Sahujem dta pre tabuku';
$strDumpSaved = 'Dump (schma) bol uloen do sboru %s.';
$strDumpXRows = 'Zobrazi %s riadkov od riadku %s.';
$strDynamic = 'dynamick';

$strEditPDFPages = 'Upravi PDF Strnky';
$strEditPrivileges = 'Upravi oprvnenia';
$strEdit = 'Upravi';
$strEffective = 'Efektvny';
$strEmptyResultSet = 'MySQL vrtil przdny vsledok (tj. nulov poet riadkov).';
$strEmpty = 'Vyprzdni';
$strEnabled = 'Zapnut';
$strEncloseInTransaction = 'Uzatvori prkazy v transakcii';
$strEndCut = 'KONIEC VSEKU';
$strEnd = 'Koniec';
$strEndRaw = 'KONIEC TOKU';
$strEngineAvailable = 'lon systm %s je na tomto MySQL servri dostupn.';
$strEngineDisabled = 'lon systm %s bol na tomto MySQL servri deaktivovan.';
$strEngines = 'Systmy';
$strEngineUnsupported = 'Tento MySQL server nepodporuje lon systm %s.';
$strEnglish = 'Anglicky';
$strEnglishPrivileges = ' Poznmka: nzvy MySQL oprvnen s uvdzan v anglitine. ';
$strError = 'Chyba';
$strErrorInZipFile = 'Chyba v ZIP archve:';
$strErrorRenamingTable = 'Chyba pri premenovan tabuky %1$s na %2$s';
$strEscapeWildcards = 'Nhradzujcim znakom _ a % by mal predchdza znak \, pokia ich nechcete poui doslovne';
$strEsperanto = 'Esperanto';
$strEstonian = 'Estnsky';
$strExcelEdition = 'Verzia Excelu';
$strExcelOptions = 'Nastavenia CSV pre Excel';
$strExecuteBookmarked = 'Spusti obben dopyt';
$strExplain = 'Vysvetli SQL';
$strExport = 'Exportova';
$strExportMustBeFile = 'Vybran typ exportu mus by uloen do sboru!';
$strExtendedInserts = 'Rozren vkladanie';
$strExtra = 'Extra';

$strFailedAttempts = 'Nepodarench pokusov';
$strFieldHasBeenDropped = 'Pole %s bolo odstrnen';
$strField = 'Pole';
$strFieldsEmpty = ' Poet pol je przdny! ';
$strFieldsEnclosedBy = 'Polia uzatvoren';
$strFieldsEscapedBy = 'Polia uveden pomocou';
$strFields = 'Polia';
$strFieldsTerminatedBy = 'Polia ukonen';
$strFileAlreadyExists = 'Sbor %s u existuje na servery, zmente nzov sboru alebo zvolte prepsanie sboru.';
$strFileCouldNotBeRead = 'Sbor sa ned preta';
$strFileNameTemplateDescriptionDatabase = 'meno databzy';
$strFileNameTemplateDescriptionServer = 'meno servera';
$strFileNameTemplateDescriptionTable = 'meno tabuky';
$strFileNameTemplateDescription = 'Tto hodnota je interpretovan pomocou %1$sstrftime%2$s, take mete poui reazec pre formtovanie dtumu a asu. Naviac bud vykonan tieto nahradenia: %3$s. Ostatn text bude zachovan.';
$strFileNameTemplateRemember = 'zapamta si vzor';
$strFileNameTemplate = 'Vzor pre nzov sboru';
$strFileToImport = 'Sbor na importovanie';
$strFixed = 'pevn';
$strFlushPrivilegesNote = 'Poznmka: phpMyAdmin zskava prva pouvateov priamo z tabuliek MySQL. Obsah tchto tabuliek sa me li od prv, ktor pouva server, ak boli tieto tabuky rune upraven. V tomto prpade sa odpora vykona %sznovunatanie prv%s predtm ako budete pokraova.';
$strFlushQueryCache = 'Vyprzdni vyrovnvaciu pam prkazov';
$strFlushTables = 'Vyprzdni (uzavrie) vetky tabuky';
$strFlushTable = 'Vyprzdni tabuku ("FLUSH")';
$strFormat = 'Formt';
$strFormEmpty = 'Chbajca poloka vo formulri !';
$strFreePages = 'Przdnych strnok';
$strFullText = 'Pln texty';
$strFunction = 'Funkcia';
$strFunctions = 'Funkcie';

$strGenBy = 'Vygenerovan';
$strGeneralRelationFeat = 'Monosti veobecnch vzahov';
$strGeneratePassword = 'Vytvori Heslo';
$strGenerate = 'Vytvori';
$strGenTime = 'Vygenerovan:';
$strGeorgian = 'Gruznina';
$strGerman = 'Nemecky';
$strGlobal = 'globlny';
$strGlobalPrivileges = 'Globlne prva';
$strGlobalValue = 'Globlna hodnota';
$strGo = 'Vykonaj';
$strGrantOption = 'Prideli';
$strGreek = 'Grtina';
$strGzip = '"gzip-ovan"';

$strHandler = 'Manipulan Rutina';
$strHasBeenAltered = 'bola zmenen.';
$strHasBeenCreated = 'bola vytvoren.';
$strHaveToShow = 'Zvolte prosm aspo jeden stpec, ktor chcete zobrazi';
$strHebrew = 'Hebrejsky';
$strHexForBinary = 'Binrne pole vypisova v estnstkovej sstave';
$strHome = 'Domov';
$strHomepageOfficial = 'Oficilne strnky phpMyAdmin';
$strHostEmpty = 'Nzov hostitea je przdny!';
$strHost = 'Hostite';
$strHTMLExcel = 'Microsoft Excel 2000';
$strHTMLExcelOptions = 'Nastavenia pre Microsoft Excel 2000';
$strHTMLWord = 'Microsoft Word 2000';
$strHTMLWordOptions = 'Nastavenia pre Microsoft Word 2000';
$strHungarian = 'Maarsky';

$strIcelandic = 'Islandina';
$strId = 'ID';
$strIdxFulltext = 'Cel text';
$strIgnoreDuplicates = 'Ignorova opakujce sa riadky';
$strIgnore = 'Ignorova';
$strIgnoreInserts = 'Poui IGNORE';
$strIgnoringFile = 'Ignorujem sbor %s';
$strImportDocSQL = 'Importova sbory docSQL';
$strImportFiles = 'Importova sbory';
$strImportFormat = 'Formt importovanho sboru';
$strImport = 'Import';
$strImportSuccessfullyFinished = 'Import bol spene ukonen, bolo vykonanch %d dopytov.';
$strIndexes = 'Indexy';
$strIndexHasBeenDropped = 'Index pre %s bol odstrnen';
$strIndex = 'Index';
$strIndexName = 'Meno indexu&nbsp;:';
$strIndexType = 'Typ indexu&nbsp;:';
$strIndexWarningMultiple = 'Pre stpec `%s` je vytvoren viac ako jeden %s k';
$strIndexWarningPrimary = 'Na stpec `%s` by nemal by nastaven PRIMARY a zrove INDEX k';
$strIndexWarningTable = 'Problmy s indexami v tabuke `%s`';
$strIndexWarningUnique = 'Na stpec `%s` by nemal by nastaven UNIQUE a zrove INDEX k';
$strInnoDBAutoextendIncrementDesc = ' Vekos, o ktor je zven automaticky sa zvujci priestor tabuky pri zaplnen.';
$strInnoDBAutoextendIncrement = 'Navenie pri automatickom zvovan';
$strInnoDBBufferPoolSizeDesc = 'Vekos pamte, ktor InnoDB pouva pre cachovanie dt a indexov tabuliek.';
$strInnoDBBufferPoolSize = 'Vekos vyrovnvacej pamte';
$strInnoDBDataFilePath = 'Sbory s dtami';
$strInnoDBDataHomeDirDesc = 'Spolon as cesty k adresru s InnoDB sbormi s dtami.';
$strInnoDBDataHomeDir = 'Domovsk adresr pre dta';
$strInnoDBPages = 'strnok';
$strInnodbStat = 'Stav InnoDB';
$strInsecureMySQL = 'Konfiguran sbor obsahuje nastavenia (root bez hesla), ktor zodpovedaj predvolenmu privilegovanmu MySQL tu. Ak MySQL server be s tmto nastavenm, nie je zabezpeen proti napadnutiu, tto bezpenostn chyba by mala by urchlene odstrnen.';
$strInsertAsNewRow = 'Vloi ako nov riadok';
$strInsertedRowId = 'Id vloenho riadku:';
$strInsertedRows = 'Vloen riadky:';
$strInsert = 'Vloi';
$strInternalNotNecessary = '* Vntorn vzah nie je nutn ak u vzah existuje v InnoDB.';
$strInternalRelations = 'Intern vzahy';
$strInUse = 'prve sa pouva';
$strInvalidAuthMethod = 'V konfigurcii je nastaven nesprvna autentifikan metda:';
$strInvalidColumn = 'Bol zadan chybn stpec (%s)!';
$strInvalidColumnCount = 'Poet stpcov mus by v ako nula.';
$strInvalidCSVFieldCount = 'Chybn poet poloiek v CSV vstupe na riadku %d.';
$strInvalidCSVFormat = 'Chybn formt v CSV vstupe na riadku %d.';
$strInvalidCSVParameter = 'Chybn parameter pre CSV import: %s';
$strInvalidDatabase = 'Chybn databza';
$strInvalidFieldAddCount = 'Muste prida aspo jeden stpec.';
$strInvalidFieldCount = 'Tabuka mus obsahova aspo jeden stpec.';
$strInvalidLDIImport = 'Tento plug-in nepodporuje import komprimovanch sborov!';
$strInvalidRowNumber = '%d nie je platn slo riadku.';
$strInvalidServerHostname = 'Chybn nzov hostu pre server %1$s. Prosm, skontrolujte konfigurciu.';
$strInvalidServerIndex = 'Chybn index serveru: "%s"';
$strInvalidTableName = 'Chybn meno tabuky';

$strJapanese = 'Japonina';
$strJoins = 'Zjednotenia';
$strJumpToDB = 'Na databzu &quot;%s&quot;.';
$strJustDeleteDescr = '&quot;Odstrnen&quot; pouvatelia bud ma k serveru ako predtm a do znovunatania prv.';
$strJustDelete = 'Iba odstrni pouvatelov z tabuliek prv.';

$strKeepPass = 'Nezmeni heslo';
$strKeyCache = 'Vyrovnvacia pam kov';
$strKeyname = 'Kov nzov';
$strKill = 'Zabi';
$strKorean = 'Krejina';

$strLandscape = 'Na rku';
$strLanguageFileNotFound = 'Jazykov sbor "%1$s" nebol njden.';
$strLanguageUnknown = 'Neznmy jazyk: %1$s.';
$strLatchedPages = 'Uzavretch strnok';
$strLatexCaption = 'Nadpis tabuky';
$strLatexContent = 'Obsah tabuky __TABLE__';
$strLatexContinuedCaption = 'Nadpis pokraovania tabuky';
$strLatexContinued = '(pokraovanie)';
$strLatexIncludeCaption = 'Zahrn nadpis tabuky';
$strLatexLabel = 'Nvestie';
$strLaTeX = 'LaTeX';
$strLaTeXOptions = 'Nastavenia pre LaTeX';
$strLatexStructure = 'truktra tabuky __TABLE__';
$strLatvian = 'Lotystina';
$strLDI = 'CSV pomocou LOAD DATA';
$strLDIImportOptions = 'Nastavenia CSV importu pomocou LOAD DATA';
$strLDILocal = 'Poui kov slovo LOCAL';
$strLengthSet = 'Dka/Nastavi*';
$strLimitNumRows = 'zznamov na strnku';
$strLinesTerminatedBy = 'Riadky ukonen';
$strLinkNotFound = 'Linka nebola njden';
$strLinksTo = 'Linkova na';
$strLithuanian = 'Litovsky';
$strLocalhost = 'Loklny';
$strLocationTextfile = 'Lokcia textovho sboru';
$strLoginInformation = 'Prihlsenie';
$strLogin = 'Login';
$strLogout = 'Odhlsi sa';
$strLogPassword = 'Heslo:';
$strLogServer = 'Server';
$strLogUsername = 'Pouvate:';
$strLongOperation = 'Tto opercia me trva vemi dlho. Chcete ju aj napriek tomu vykona?';

$strMaxConnects = 'max. sasnch pripojen';
$strMaximalQueryLength = 'Maximlna vekos vytvorenho prkazu';
$strMaximumSize = 'Maximlna vekos: %s%s';
$strMbExtensionMissing = 'Mbstring rozrenie pre PHP nebolo njden a zjavne pouvate viacbajtov znakov sadu. Bez tohto rozrenia nie je phpMyAdmin schopn korektne rozdeova reazce kdovan v tchto znakovch sadch a me to vies k neakanm vsledkom.';
$strMbOverloadWarning = 'V nastaven PHP je aktvna funkcia mbstring.func_overload, ktor nie je kompatibiln s phpMyAdmin-om a me spsobi stratu dt!';
$strMIME_available_mime = 'Dostupn MIME typy';
$strMIME_available_transform = 'Dostupn transformcie';
$strMIME_description = 'Popis';
$strMIME_MIMEtype = 'MIME typ';
$strMIME_nodescription = 'Nie je dostupn iadny popis pre tto transformciu.<br />Kontaktujte autora, ktor %s vytra.';
$strMIME_transformation_note = 'Pre zoznam dostupnch parametrov a ich MIME typov kliknite na %spopisy transformci';
$strMIME_transformation_options_note = 'Prosm zadajte hodnoty pre parametre transformcie v nasledujcom tvare: \'a\',\'b\',\'c\'...<br />Ak potrebujete poui sptn lomtko ("\") alebo jednoduch vodzovky ("\'") medzi tmito hodnotami, vlote pred nich sptn lomtko (napr. \'\\\\xyz\' alebo \'a\\\'b\').';
$strMIME_transformation_options = 'Parametre transformcie';
$strMIME_transformation = 'Transformcia pri prehliadan';
$strMIMETypesForTable = 'MIME TYPY PRE TABUKU';
$strMIME_without = 'MIME typy zobrazen kurzvou nemaj vlastn transforman funkciu';
$strModifications = 'Zmeny boli uloen';
$strModifyIndexTopic = 'Modifikova index';
$strModify = 'Zmeni';
$strMoveTableOK = 'Tabuka %s bola presunut do %s.';
$strMoveTable = 'Presun tabuku do (databza<b>.</b>tabuka):';
$strMoveTableSameNames = 'Ned sa presun tabuka sama do seba!';
$strMultilingual = 'mnohojazyn';
$strMyISAMDataPointerSizeDesc = 'Prednastaven vekos smernka na dta v bajtoch, pouvan pri vytvran MyISAM tabuliek prkazom CREATE TABLE, v prpade ke nie je zadan hodnota MAX_ROWS.';
$strMyISAMDataPointerSize = 'Vekos smernka na dta';
$strMyISAMMaxExtraSortFileSizeDesc = 'Ak je vekos doasnho sboru, pouitho pre rchlejie vytvranie MyISAM indexov, via ako pri pouit cache, pouije sa metda cachovania indexu.';
$strMyISAMMaxExtraSortFileSize = 'Maximlna vekos doasnch sborov pre vytvorenie indexu';
$strMyISAMMaxSortFileSizeDesc = 'Maximlna vekos doasnho sboru, ktor me MySQL poui pri obnove MyISAM indexu (poas vykonvania prkazov REPAIR TABLE, ALTER TABLE alebo LOAD DATA INFILE).';
$strMyISAMMaxSortFileSize = 'Maximlna vekos doasnch zoraovacch sborov';
$strMyISAMRecoverOptionsDesc = 'Reim automatickej obnovy pokodench MyISAM tabuliek, ktor sa d nastavi parametrom --myisam-recover pri span servra.';
$strMyISAMRecoverOptions = 'Reim automatickej obnovy';
$strMyISAMRepairThreadsDesc = 'Ak je tto hodnota vyia ako 1, poas procesu Opravy Zoradenm s indexy MyISAM tabuky vytvran paralelne (kad index vo svojom vlkne).';
$strMyISAMRepairThreads = 'Opravn vlkna';
$strMyISAMSortBufferSizeDesc = 'Pam, ktor je alokovan pri zoraovan MyISAM indexov poas vykonvania prkazu REPAIR TABLE, alebo pri vytvran indexov prkazmi CREATE INDEX alebo ALTER TABLE.';
$strMyISAMSortBufferSize = 'Vekos zoraovacej pamte';
$strMySQLCharset = 'Znakov sada v MySQL';
$strMysqlClientVersion = 'Verzia MySQL klienta';
$strMySQLConnectionCollation = 'Overenie MySQL spojenia';
$strMySQLSaid = 'MySQL hlsi: ';
$strMySQLShowProcess = 'Zobrazi procesy';
$strMySQLShowStatus = 'Zobrazi MySQL informcie o behu';
$strMySQLShowVars = 'Zobrazi MySQL systmov premenn';

$strName = 'Nzov';
$strNext = 'al';
$strNoActivity = 'Boli ste neaktvni viac ako %s seknd, prihlste sa prosm znovu';
$strNoDatabasesSelected = 'Neboli vybran iadne databzy.';
$strNoDatabases = 'iadne databzy';
$strNoDataReceived = 'Neboli prijat iadne dta na import. Bu nebol natan iadny sbor alebo jeho vekos prekroila maximlnu vekos povolen v PHP. Pozri FAQ 1.16.';
$strNoDescription = 'bez Popisu';
$strNoDetailsForEngine = 'Pre tento lon systm nie s dostupn iadne podrobnejie informcie.';
$strNoDropDatabases = 'Monos "DROP DATABASE" vypnut.';
$strNoExplain = 'Preskoi vysvetlenie SQL';
$strNoFilesFoundInZip = 'V ZIP archve neboli njden iadne sbory!';
$strNoFrames = 'phpMyAdmin funguje lepie s prehliadami podporujcimi <b>rmy</b>.';
$strNoIndex = 'Nebol definovan iadny index!';
$strNoIndexPartsDefined = 'asti indexu neboli definovan!';
$strNoModification = 'iadna zmena';
$strNone = 'iadny';
$strNo = 'Nie';
$strNoOptions = 'Tento formt nem iadne nastavenia';
$strNoPassword = 'iadne heslo';
$strNoPermission = 'Web server nem oprvenia na uloenie do sboru %s.';
$strNoPhp = 'bez PHP kdu';
$strNoPrivileges = 'iadne oprvnenia';
$strNoRights = 'Nemte dostaton prva na vykonanie tejto akcie!';
$strNoRowsSelected = 'Nebol vybran iadny riadok';
$strNoSpace = 'Nedostatok miesta pre uloenie sboru %s.';
$strNoTablesFound = 'Neboli njden iadne tabuky v tejto datbaze.';
$strNoThemeSupport = 'Zmena vzhadu nie je podporovan, skontrolujte si nastavenia a vzhady v adresri %s.';
$strNotNumber = 'Toto nie je slo!';
$strNotOK = 'chyba';
$strNotSet = 'Tabuka <b>%s</b> nebola njden alebo nie je nastaven v %s';
$strNoUsersFound = 'Nebol njden iadny pouvate.';
$strNoValidateSQL = 'Preskoi potvrdenie platnosti SQL';
$strNull = 'Nulov';
$strNumberOfFields = 'Poet pol';
$strNumSearchResultsInTable = '%s vskyt(ov)v tabuke <i>%s</i>';
$strNumSearchResultsTotal = '<b>Celkovo:</b> <i>%s</i> vskyt(ov)';
$strNumTables = 'Tabuky';

$strOK = 'OK';
$strOpenDocumentSpreadsheetOptions = 'Nastavenia pre tabukov procesor Open Document';
$strOpenDocumentSpreadsheet = 'Tabukov procesor Open Document';
$strOpenDocumentText = 'Open Document Text';
$strOpenDocumentTextOptions = 'Nastavenia pre Open Document Text';
$strOpenNewWindow = 'Otvori nov okno phpMyAdmina';
$strOperations = 'Opercie';
$strOperator = 'Opertor';
$strOptimizeTable = 'Optimalizova tabuku';
$strOr = 'alebo';
$strOverhead = 'Naviac';
$strOverwriteExisting = 'Prepsa existujci sbor(y)';

$strPageNumber = 'slo strnky:';
$strPagesToBeFlushed = 'Strnok urench k uvoneniu';
$strPaperSize = 'Vekos strnky';
$strPartialImport = 'iaston import';
$strPartialText = 'iaston texty';
$strPasswordChanged = 'Heslo pre %s bolo spene zmenen.';
$strPasswordEmpty = 'Heslo je przdne!';
$strPasswordHashing = 'Hashovanie hesla';
$strPassword = 'Heslo';
$strPasswordNotSame = 'Hesl sa nezhoduj!';
$strPdfDbSchema = 'Schma databzy "%s"  - Strana %s';
$strPdfInvalidTblName = 'Tabuka "%s" neexistuje!';
$strPdfNoTables = 'iadne tabuky';
$strPDFOptions = 'Nastavenia pre PDF';
$strPDF = 'PDF';
$strPDFReportTitle = 'Titulok vpisu';
$strPerHour = 'za hodinu';
$strPerMinute = 'za mintu';
$strPerSecond = 'za sekundu';
$strPersian = 'Pertina';
$strPhoneBook = 'adresr';
$strPHP40203 = 'Pouvate PHP 4.2.3, ktor ma vnu chybu pri prci s viac bajtovmi znakmi (mbstring). V PHP je tto chyba zdokumentovan pod slom 19404. Nedoporuuje sa pouva tto verziu PHP s phpMyAdminom.';
$strPHPVersion = 'Verzia PHP';
$strPhp = 'Vytvori PHP kd';
$strPmaDocumentation = 'phpMyAdmin Dokumentcia';
$strPmaUriError = 'Direktva <tt>$cfg[\'PmaAbsoluteUri\']</tt> v konfiguranom sbore MUS by nastaven!';
$strPolish = 'Potina';
$strPortrait = 'Na vku';
$strPos1 = 'Zaiatok';
$strPrevious = 'Predchdzajci';
$strPrimaryKeyHasBeenDropped = 'Primrny k bol zruen';
$strPrimaryKeyName = 'Nzov primrneho ka mus by... PRIMARY!';
$strPrimaryKeyWarning = '("PRIMARY" <b>mus</b> by <b>iba</b> meno primrneho ka!)';
$strPrimary = 'Primrny';
$strPrintViewFull = 'Nhad tlae (s kompletnmi textami)';
$strPrintView = 'Nhad k tlai';
$strPrint = 'Vytlai';
$strPrivDescAllPrivileges = 'Vetky oprvnenia okrem GRANT.';
$strPrivDescAlter = 'Povol meni truktru existujcich tabuliek.';
$strPrivDescAlterRoutine = 'Umouje upravova a odstraova uloen procedry.';
$strPrivDescCreateDb = 'Povol vytvranie novch databz a tabuliek.';
$strPrivDescCreateRoutine = 'Umouje vytvra uloen procedry.';
$strPrivDescCreateTbl = 'Povol vytvranie novch tabuliek.';
$strPrivDescCreateTmpTable = 'Povol vytvranie doasnch tabuliek.';
$strPrivDescCreateUser = 'Umouje vytvra, odstraova a premenovva pouvatesk kont.';
$strPrivDescCreateView = 'Umouje vytvra nov pohady.';
$strPrivDescDelete = 'Povol mazanie dt.';
$strPrivDescDropDb = 'Povol odstraovanie databz a tabuliek.';
$strPrivDescDropTbl = 'Povol odstraovanie tabuliek.';
$strPrivDescExecute5 = 'Umouje spa uloen procedry.';
$strPrivDescExecute = 'Povol spanie uloench procedr. Nefunguje v tejto verzii MySQL.';
$strPrivDescFile = 'Povol importovanie a exportovanie dt zo/do sborov na serveri.';
$strPrivDescGrant = 'Povol pridvanie uivatelov a prv bez znovunatania tabuliek prv.';
$strPrivDescIndex = 'Povol vytvranie a mazanie indexov.';
$strPrivDescInsert = 'Povol vkladanie a nahradzovanie dt.';
$strPrivDescLockTables = 'Povol zmaknutie tabuliek pre aktulne vlkno.';
$strPrivDescMaxConnections = 'Obmedz poet novch spojen, ktor me pouvate vytvori za hodinu.';
$strPrivDescMaxQuestions = 'Obmedz poet dopytov, ktor me pouvate odosla za hodinu.';
$strPrivDescMaxUpdates = 'Obmedz poet prkazov meniacich tabuku alebo databzu, ktor me pouvate odosla za hodinu.';
$strPrivDescMaxUserConnections = 'Obmedzuje poet simultnnych pripojen pouvatea.';
$strPrivDescProcess3 = 'Povol zabjanie procesov inm pouvatelom.';
$strPrivDescProcess4 = 'Povol prezeranie kompletnch dopytov v zozname procesov.';
$strPrivDescReferences = 'Nefunguje v tejto verzii MySQL.';
$strPrivDescReload = 'Povol znovunatanie nastaven a vyprzdovanie vyrovnvacch pamt serveru.';
$strPrivDescReplClient = 'Povol pouvateovi zisti kde je hlavn / pomocn server.';
$strPrivDescReplSlave = 'Potrebn pre replikciu pomocnch serverov.';
$strPrivDescSelect = 'Povol tanie dt.';
$strPrivDescShowDb = 'Povol prstup ku kompletnmu zoznamu databz.';
$strPrivDescShowView = 'Umouje spa prkazy so SHOW CREATE VIEW.';
$strPrivDescShutdown = 'Povol vypnutie serveru.';
$strPrivDescSuper = 'Povol spojenie aj v prpade, e bol dosiahnut maximlny poet spojen. Potrebn pre vinu operci pri sprve serveru ako nastavovanie globlny premennch alebo zabjanie procesov inch pouvateov.';
$strPrivDescUpdate = 'Povol menenie dt.';
$strPrivDescUsage = 'iadne prva.';
$strPrivileges = 'Oprvnenia';
$strPrivilegesReloaded = 'Prva boli spene znovunatan.';
$strProcedures = 'Procedry';
$strProcesses = 'Procesy';
$strProcesslist = 'Zoznam procesov';
$strProtocolVersion = 'Verzia protokolu';
$strPutColNames = 'Prida nzvy pol na prv riadok';

$strQBEDel = 'Zmaza';
$strQBE = 'Dopyt poda prkladu';
$strQBEIns = 'Vloi';
$strQueryCache = 'Vyrovnvacia pam prkazov';
$strQueryFrame = 'SQL okno';
$strQueryOnDb = ' SQL dopyt v databze <b>%s</b>:';
$strQueryResultsOperations = 'Opercie s vsledkami dopytu';
$strQuerySQLHistory = 'SQL histria';
$strQueryStatistics = '<b>Query statistics</b>: Since its startup, %s queries have been sent to the server.';
$strQueryTime = 'Dopyt zabral %01.4f sek.';
$strQueryType = 'Typ dopytu';
$strQueryWindowLock = 'Neprepisova tento dopyt z hlavnho okna';

$strReadRequests = 'Poiadavkov na tanie';
$strReceived = 'Prijat';
$strRecords = 'Zznamov';
$strReferentialIntegrity = 'Skontrolova referenn integritu:';
$strRefresh = 'Obnovi';
$strRelationalSchema = 'Relan schma';
$strRelationNotWorking = 'Prdavn vlastnosti pre prcu s prepojenmi tabukami boli deaktivovan. Ak chcete zisti preo, kliknite %ssem%s.';
$strRelationsForTable = 'PREPOJENIA PRE TABUKU';
$strRelations = 'Prepojenia';
$strRelationView = 'Zobrazi prepojenia';
$strReloadingThePrivileges = 'Znovunatanie prv';
$strReloadPrivileges = 'Znovunata prstupov prva';
$strRemoveSelectedUsers = 'Odstrni vybranch pouvateov';
$strRenameDatabaseOK = 'Databza %s bola premenovan na %s';
$strRenameTableOK = 'Tabuka %s bola premenovan na %s';
$strRenameTable = 'Premenova tabuku na';
$strRepairTable = 'Opravi tabuku';
$strReplaceNULLBy = 'Nahradi NULL hodnoty';
$strReplaceTable = 'Nahradi dta v tabuke sborom';
$strReplication = 'Replikcia';
$strReset = 'Pvodn (Reset)';
$strResourceLimits = 'Obmedzenie zdrojov';
$strReType = 'Potvrdi';
$strRevokeAndDeleteDescr = 'Uvatelia bud ma stle prvo USAGE (pouvanie) a do znovunatania prv.';
$strRevokeAndDelete = 'Odobranie vetkch aktvnych prv pouvateom a ich nsledn odstrnenie.';
$strRevokeMessage = 'Boli zruen oprvnenia pre %s';
$strRevoke = 'Zrui';
$strRomanian = 'Rumuntina';
$strRowLength = 'Dka riadku';
$strRowsFrom = 'riadky zanaj od';
$strRowSize = ' Vekos riadku ';
$strRowsModeFlippedHorizontal = 'vodorovnom (otoen hlaviky)';
$strRowsModeHorizontal = 'horizontlnom';
$strRowsModeOptions = 'v(o) %s mde a opakova hlaviky po kadch %s bunkch';
$strRowsModeVertical = 'vertiklnom';
$strRows = 'Riadkov';
$strRowsStatistic = 'tatistika riadku';
$strRunning = 'be na %s';
$strRunQuery = 'Odoli dopyt';
$strRunSQLQueryOnServer = 'Spusti SQL prkaz(y) na servri %s';
$strRunSQLQuery = 'Spusti SQL dopyt/dopyty na databzu %s';
$strRussian = 'Rutina';

$strSaveOnServer = 'Uloi na server do adresra %s';
$strSave = 'Uloi';
$strScaleFactorSmall = 'Mierka je prli mala na roztiahnutie schmy na strnku';
$strSearchFormTitle = 'Hada v databze';
$strSearch = 'Hada';
$strSearchInTables = 'V tabuke(ch):';
$strSearchNeedle = 'Slovo() alebo hodnotu(y), ktor chcete vyhada (nahradzujci znak: "%"):';
$strSearchOption1 = 'najmenej jedno zo slov';
$strSearchOption2 = 'vetky slov';
$strSearchOption3 = 'presn vraz';
$strSearchOption4 = 'ako regulrny vraz';
$strSearchResultsFor = 'Prehada vsledky na "<i>%s</i>" %s:';
$strSearchType = 'Njdi:';
$strSecretRequired = 'Nastavte prosm k pre ifrovanie cookies v konfiguranom sbore (blowfish_secret).';
$strSelectADb = 'Prosm vyberte si databzu';
$strSelectAll = 'Oznai vetko';
$strSelectBinaryLog = 'Vyberte binrny log na zobrazenie';
$strSelectFields = 'Zvoli pole (najmenej jedno):';
$strSelectNumRows = 'v dopyte';
$strSelectTables = 'Vybra Tabuky';
$strSend = 'Poli';
$strSent = 'Odoslan';
$strServerChoice = 'Voba serveru';
$strServerNotResponding = 'Server neodpoved';
$strServer = 'Server';
$strServers = 'Servery';
$strServerStatusDelayedInserts = 'Odloen vloenia';
$strServerStatus = 'Stav serveru';
$strServerStatusUptime = 'Tento server be %s. Bol spusten %s.';
$strServerTabVariables = 'Premenn';
$strServerTrafficNotes = '<b>Server traffic</b>: These tables show the network traffic statistics of this MySQL server since its startup.';
$strServerVars = 'Premenn a nastavenia serveru';
$strServerVersion = 'Verzia serveru';
$strSessionValue = 'Hodnota sedenia';
$strSetEnumVal = 'Ak je pole typu "enum" alebo "set", prosm zadvajte hodnoty v tvare: \'a\',\'b\',\'c\'...<br />Ak dokonca potrebujete zada sptn lomtko ("\") alebo apostrof ("\'") pri tchto hodnotch, zadajte ich naprklad takto \'\\\\xyz\' alebo \'a\\\'b\'.';
$strShowAll = 'Zobrazi vetko';
$strShowColor = 'Zobrazi farbu';
$strShowDatadictAs = 'Formt dtovho slovnka';
$strShowFullQueries = 'Zobrazi kompletn dopyty';
$strShowGrid = 'Zobrazi mrieku';
$strShowingBookmark = 'Zobrazujem obben prkaz';
$strShowingRecords = 'Ukza zznamy ';
$strShowOpenTables = 'Zobrazi otvoren tabuky';
$strShowPHPInfo = 'Zobrazi informcie o PHP';
$strShowSlaveHosts = 'Zobrazi podriaden hosty';
$strShowSlaveStatus = 'Zobrazi stav podriadench hostov';
$strShowStatusBinlog_cache_disk_useDescr = 'Poet transakci, ktor vyuili doasn vyrovnvaciu pam binrneho logu, ale zrove prekroili hodnotu binlog_cache_size a museli tak poui doasn sbor na uloenie prkazov transakcie.';
$strShowStatusBinlog_cache_useDescr = 'Poet transakci, ktor vyuili vyrovnvaciu pam binrneho logu.';
$strShowStatusCreated_tmp_disk_tablesDescr = 'Poet doasnch tabuliek automaticky vytvorench servrom pri vykonvan prkazov. Ak je hodnota Created_tmp_disk_tables prli vysok, mte zvi hodnotu tmp_table_size, aby boli doasn tabuky ukladan do pamte a nie na disk.';
$strShowStatusCreated_tmp_filesDescr = 'Poet doasnch sborov vytvorench servrom mysqld.';
$strShowStatusCreated_tmp_tablesDescr = 'Poet doasnch, v pamti uloench tabuliek, vytvorench servrom pri vykonvan prkazov.';
$strShowStatusDelayed_errorsDescr = 'Poet riadkov pridanch prkazom INSERT DELAYED, pri ktorch sa vyskytla chyba (pravdepodobne opakujci sa k).';
$strShowStatusDelayed_insert_threadsDescr = 'Poet vlkien pouvanch prkazmi INSERT DELAYED. Kad samostatn tabuka, na ktor je pouit prkaz INSERT DELAYED, ma svoje vlastn vlkno.';
$strShowStatusDelayed_writesDescr = 'Poet riadkov vloench prkazom INSERT DELAYED.';
$strShowStatusFlush_commandsDescr  = 'Poet vykonanch prkazov FLUSH.';
$strShowStatusHandler_commitDescr = 'Poet internch prkazov COMMIT.';
$strShowStatusHandler_deleteDescr = 'Kokokrt bol z tabuky odstrnen riadok.';
$strShowStatusHandler_discoverDescr = 'MySQL server me zasla poiadavku NDB Clustru, i nevie o existencii tabuky s danm menom. Tento proces sa nazva objavovanie. Handler_discover zobrazuje poet doposia objavench tabuliek.';
$strShowStatusHandler_read_firstDescr = 'Poet pretan prvej poloky indexu. Ak je tto hodnota prli vysok, znamen to e server vykonva prli vea kompletnch prechdzan indexov; naprklad, SELECT col1 FROM foo, za predpokladu e col1 je indexovan.';
$strShowStatusHandler_read_keyDescr = 'Poet poiadavkov na natanie riadku poda ka. Ak je tto hodnota vysok, je to dobrm znamenm e s prkazy a tabuky sprvne indexovan.';
$strShowStatusHandler_read_nextDescr = 'Poet poiadavkov na natanie nasledujceho riadku v porad poda ka. Tto hodnota sa zvyuje ak sa natava indexovan stpec v danom rozsahu alebo ak sa vykonva prehadvanie indexu.';
$strShowStatusHandler_read_prevDescr = 'Poet poiadavkov na natanie predchdzajceho riadku poda ka. Tto tacia metda sa pouiva hlavne na optimalizciu prkazov typu ORDER BY ... DESC.';
$strShowStatusHandler_read_rndDescr = 'Poet poiadavkov na natanie riadku na zklade uritej pozcie. Tto hodnota je vysok, ak sa vykonva vea prkazov, ktor si vyaduj zoradenie vsledku. Pravdepodobne sa pouiva vea prkazov, kvli ktorm mus MySQL kompletne prehadva tabuky, alebo sa pouvaj zjednotenia, ktor sprvne nevyuvaj ke.';
$strShowStatusHandler_read_rnd_nextDescr = 'Poet poiadavkov na natanie nasledujceho riadku. Tto hodnota je vysok, ak sa vykonva vea kompletnch prehadvan tabuliek. Znamen to e bu tabuky nie s sprvne indexovan alebo prkazy nedostatone vyuvaj dostupn indexy.';
$strShowStatusHandler_rollbackDescr = 'Poet internch prkazov ROLLBACK.';
$strShowStatusHandler_updateDescr = 'Poet poiadavkov na zmenu zznamu (riadku) v tabuke.';
$strShowStatusHandler_writeDescr = 'Poet poiadavkov na vloenie novho zznamu (riadku) do tabuky.';
$strShowStatusInnodb_buffer_pool_pages_dataDescr = 'Poet strnok obsahujcich dta (neistch aj istch).';
$strShowStatusInnodb_buffer_pool_pages_dirtyDescr = 'Poet neistch strnok.';
$strShowStatusInnodb_buffer_pool_pages_flushedDescr = 'Poet strnok, na ktor je poiadavka na vyprzdnenie.';
$strShowStatusInnodb_buffer_pool_pages_freeDescr = 'Poet vonch strnok.';
$strShowStatusInnodb_buffer_pool_pages_latchedDescr = 'Poet uzamknutch strnok v InnoDB vyrovnvacej pamti. Z tchto strnok sa momentlne ta alebo zapisuje, prpadne nemu by vyprzdnen ani odstrnen z nejakho inho dvodu.';
$strShowStatusInnodb_buffer_pool_pages_miscDescr = 'Poet momentlne neprstupnch strnok z dvodu asti na administratvnych eloch ako napr. uzamknanie riadkov alebo adaptvny hash index. Tto hodnota sa tie me vypota ako Innodb_buffer_pool_pages_total - Innodb_buffer_pool_pages_free - Innodb_buffer_pool_pages_data.';
$strShowStatusInnodb_buffer_pool_pages_totalDescr = 'Celkov poet strnok vo vyrovnvacej pamti InnoDB.';
$strShowStatusInnodb_buffer_pool_read_ahead_rndDescr = 'Poet "nhodnch" predtan vykonanch InnoDB. Tto situcia nastva pri prkazoch, ktor prehadvaj vek as tabuky, ale v nhodnom porad.';
$strShowStatusInnodb_buffer_pool_read_ahead_seqDescr = 'Poet sekvennch predtan vykonanch InnoDB. Tto situcia nastva pri vykonvan sekvennho prehadvania celej tabuky.';
$strShowStatusInnodb_buffer_pool_read_requestsDescr = 'Poet poiadavkov na logick natavanie.';
$strShowStatusInnodb_buffer_pool_readsDescr = 'Poet logickch natan, ktor sa nemohli vykona z vyrovnvacej pamte a namiesto toho bolo vykonan natanie celej jednej strnky.';
$strShowStatusInnodb_buffer_pool_wait_freeDescr = 'Normlne sa zpis do vyrovnvacej pamte InnoDB vykonva v pozad. Ak vak nie s pri poiadavke na natanie alebo vytvorenie strnky dostupn iadne ist strnky, je potrebn poka na ich vyistenie. Tto hodnota zobrazuje poet tchto akan a ak bola sprvne nastaven vekos vyrovnvacej pamte, mala by by nzka.';
$strShowStatusInnodb_buffer_pool_write_requestsDescr = 'Poet zpisov do vyrovnvacej pamte InnoDB.';
$strShowStatusInnodb_data_fsyncsDescr = 'Poet vykonanch fsync() operci.';
$strShowStatusInnodb_data_pending_fsyncsDescr = 'Aktulny poet prebiehajcich fsync() operci.';
$strShowStatusInnodb_data_pending_readsDescr = 'Poet aktulne prebiehajcich natavan.';
$strShowStatusInnodb_data_pending_writesDescr = 'Poet aktulne prebiehajcich zpisov.';
$strShowStatusInnodb_data_readDescr = 'Mnostvo u natanch dt, v bajtoch.';
$strShowStatusInnodb_data_readsDescr = 'Celkov poet natan dt.';
$strShowStatusInnodb_data_writesDescr = 'Celkov poet zpisov dt.';
$strShowStatusInnodb_data_writtenDescr = 'Mnostvo u zapsanch dt, v bajtoch.';
$strShowStatusInnodb_dblwr_pages_writtenDescr = 'Poet vykonanch dvojitch zpisov a poet strnok zapsanch pre tento el.';
$strShowStatusInnodb_dblwr_writesDescr = 'Poet vykonanch dvojitch zpisov a poet strnok zapsanch pre tento el.';
$strShowStatusInnodb_log_waitsDescr = 'Poet akan na vyprzdnenie vyrovnvacej pamte logu z dvodu jej zaplnenia.';
$strShowStatusInnodb_log_write_requestsDescr = 'Poet poiadaviek na zpis do logovacieho sboru.';
$strShowStatusInnodb_log_writesDescr = 'Poet fyzickch zpisov do logovacieho sboru.';
$strShowStatusInnodb_os_log_fsyncsDescr = 'Poet fsync zpisov vykonanch na logovacom sbore.';
$strShowStatusInnodb_os_log_pending_fsyncsDescr = 'Poet prebiehajcich synchronizci logovacieho sboru.';
$strShowStatusInnodb_os_log_pending_writesDescr = 'Poet prebiehajcich zpisov do logovacieho sboru.';
$strShowStatusInnodb_os_log_writtenDescr = 'Mnostvo bajtov zapsanch do logovacieho sboru.';
$strShowStatusInnodb_pages_createdDescr = 'Poet vytvorench strnok.';
$strShowStatusInnodb_page_sizeDescr = 'Vekos nakompilovanej InnoDB strnky (prednastavench je 16KB). Viacero hodnt sa udva v strnkach; pomocou vekosti strnky je mon ich premeni na bajty.';
$strShowStatusInnodb_pages_readDescr = 'Poet natanch strnok.';
$strShowStatusInnodb_pages_writtenDescr = 'Poet zapsanch strnok.';
$strShowStatusInnodb_row_lock_current_waitsDescr = 'Poet zmkov na riadky, na ktor sa ak.';
$strShowStatusInnodb_row_lock_time_avgDescr = 'Priemern as potrebn na zskanie zmku na riadok, v milisekundch.';
$strShowStatusInnodb_row_lock_timeDescr = 'Celkov as potrebn na zskanie zmku na riadok, v milisekundch.';
$strShowStatusInnodb_row_lock_time_maxDescr = 'Maximlny as potrebn na zskanie zmku na riadok, v milisekundch.';
$strShowStatusInnodb_row_lock_waitsDescr = 'Kokokrt sa muselo aka na zmok na riadok.';
$strShowStatusInnodb_rows_deletedDescr = 'Poet zznamov (riadkov) odstrnench z InnoDB tabuliek.';
$strShowStatusInnodb_rows_insertedDescr = 'Poet zznamov (riadkov) vloench do InnoDB tabuliek.';
$strShowStatusInnodb_rows_readDescr = 'Poet natanch zznamov (riadkov) z InnoDB tabuliek.';
$strShowStatusInnodb_rows_updatedDescr = 'Poet upravench zznamov (riadkov) v InnoDB tabukch.';
$strShowStatusKey_blocks_not_flushedDescr = 'Poet zmenench kovch blokov vo vyrovnvacej pamti kov, ktor ete neboli zapsan na disk. Predtm sa tto hodnota nazvala Not_flushed_key_blocks.';
$strShowStatusKey_blocks_unusedDescr = 'Poet nevyuitch blokov vo vyrovnvacej pamti kov. Z tejto hodnoty mete zisti koko vyrovnvacej pamte sa prve pouva.';
$strShowStatusKey_blocks_usedDescr = 'Poet vyuitch blokov vo vyrovnvacej pamti kov. Tto hodnota uruje najvie mnostvo blokov, ktor kedy naraz pouit.';
$strShowStatusKey_read_requestsDescr = 'Poet poiadavkov na natanie kovho bloku z vyrovnvacej pamti.';
$strShowStatusKey_readsDescr = 'Poet natan kovho bloku priamo z disku. Ak je tto hodnota prli vek, vinou to znamen, e vekos vyrovnvacej pamti (key_buffer_size) je prli mal. spenos vyrovnvacej pamte si mte vypota zo vzahu Key_reads/Key_read_requests.';
$strShowStatusKey_write_requestsDescr = 'Poet poiadavkov na zpis kovho bloku do vyrovnvacej pamti.';
$strShowStatusKey_writesDescr = 'Poet fyzickch zpisov kovho bloku na disk.';
$strShowStatusLast_query_costDescr = 'Celkov nklady na posledn kompilovan prkaz, vypotan optimizrom prkazov. Uiton na porovnvanie nkladov na rzne prkazy pre t ist poiadavku. Prednastaven hodnota 0 znamen, e doposia neboli skompilovan iadne prkazy.';
$strShowStatusNot_flushed_delayed_rowsDescr = 'Poet riadkov akajcich na zpis cez INSERT DELAY.';
$strShowStatusOpened_tablesDescr = 'Poet doposia otvorench tabuliek. Ak je tto hodnota prli vysok, pravdepodobne je vyrovnvacia pam pre tabuky prli mal.';
$strShowStatusOpen_filesDescr = 'Poet otvorench sborov.';
$strShowStatusOpen_streamsDescr = 'Poet otvorench streamov (vinou vyuvan na logovanie).';
$strShowStatusOpen_tablesDescr = 'Poet prve otvorench tabuliek.';
$strShowStatusQcache_free_blocksDescr = 'Mnostvo vonch pamovch blokov vo vyrovnvacej pamti prkazov.';
$strShowStatusQcache_free_memoryDescr = 'Vekos vonej pamti pre vyrovnvaciu pam prkazov.';
$strShowStatusQcache_hitsDescr = 'Poet zsahov vyrovnvacej pamti.';
$strShowStatusQcache_insertsDescr = 'Poet prkazov pridanch do vyrovnvacej pamti.';
$strShowStatusQcache_lowmem_prunesDescr = 'Poet prkazov, ktor boli odstrnen z vyrovncej pamti na uvonenie pamti pre nov prkazy. Tto hodnota vm me pomc pri upravovan vekosti vyrovnvacej pamti prkazov. Na vber prkazov na odstrnenie z vyrovnvacej pamti sa pouva stratgia LRU (tzn. najdlhie nepouit prkazy bud odstrnen ako prv).';
$strShowStatusQcache_not_cachedDescr = 'Poet prkazov neumiestnench do vyrovnvacej pamti (nie s cachovaten alebo nevyhovuj nastaveniu query_cache_type).';
$strShowStatusQcache_queries_in_cacheDescr = 'Poet prkazov registrovanch vo vyrovnvacej pamti.';
$strShowStatusQcache_total_blocksDescr = 'Celkov mnostvo blokov vo vyrovnvacej pamti prkazov.';
$strShowStatusReset = 'Vynulova';
$strShowStatusRpl_statusDescr = 'Stav failsafe replikcie (zatia neimplementovan).';
$strShowStatusSelect_full_joinDescr = 'Poet spojen, ktor nevyuvaj indexy. Ak sa tto hodnota nerovn 0, mali by ste starostlivo skontrolova indexy vaich tabuliek.';
$strShowStatusSelect_full_range_joinDescr = 'Poet spojen, ktor na referennej tabuke vyuili intervalov vyhadvanie.';
$strShowStatusSelect_range_checkDescr = 'Poet spojen bez kov, ktor kontrolovali pouitie ka na kadom riadku (ak tto hodnota nie je 0, mali by ste starostlivo skontrolova indexy vaich tabuliek).';
$strShowStatusSelect_rangeDescr = 'Poet spojen, ktor na prvej tabuke vyuili intervalov vyhadvanie (tto hodnota nie je kritick ani v prpade, e je vysok).';
$strShowStatusSelect_scanDescr = 'Poet spojen, ktor vykonali kompletn prehadanie prvej tabuky.';
$strShowStatusSlave_open_temp_tablesDescr = 'Poet doasnch tabuliek, otvorench podriadenm SQL vlknom.';
$strShowStatusSlave_retried_transactionsDescr = 'Celkov poet (od spustenia) pokusov replikanho podriadenho SQL vlkna o znovuobnovenie transakcie.';
$strShowStatusSlave_runningDescr = 'Tto poloka obsahuje hodnotu ON ak je tento server podriadenm a je pripojen k prislchajcemu nadriadenmu servru.';
$strShowStatusSlow_launch_threadsDescr = 'Poet vlkien, ktorch vytvorenie zabralo viac ako je hodnota slow_launch_time.';
$strShowStatusSlow_queriesDescr = 'Poet prkazov, ktorch vykonanie zabralo viac ako je hodnota long_query_time.';
$strShowStatusSort_merge_passesDescr = 'Poet zluovacch prechodov, ktor musel vykona zoraovac algoritmus. Ak je tto hodnota prlis vek, mali by ste pouvaova nad zvenm hodnoty systmovho nastavania sort_buffer_size.';
$strShowStatusSort_rangeDescr = 'Poet rozsahom obmedzench zoraovan.';
$strShowStatusSort_rowsDescr = 'Poet zoradench riadkov.';
$strShowStatusSort_scanDescr = 'Poet zoraden uskutonench prehadvanm tabuky.';
$strShowStatusTable_locks_immediateDescr = 'Poet zmkov tabuliek, ktor boli zskan okamite.';
$strShowStatusTable_locks_waitedDescr = 'Poet prpadov ke sa zmok tabuky nedal zska okamite a bolo nutn vyka. Ak je tto hodnota vysok a mte problmy s vkonom, mali by ste najprv optimalizova vae prkazy a potom bu rozdeli tabuku/tabuky alebo poui replikciu.';
$strShowStatusThreads_cachedDescr = 'Poet vlkien vo vyrovnvacej pamti. spenos tejto vyrovnvacej pamti sa d vypota zo vzahu Threads_created/Connections. Ak je tto hodnota v ervenom, mali by ste zvi hodnotu thread_cache_size.';
$strShowStatusThreads_connectedDescr = 'Poet momentlne otvorench spojen.';
$strShowStatusThreads_createdDescr = 'Poet vlkien vytvorench na zaobchdzanie so spojeniami. Ak je hodnota Threads_created vysok, mohli by ste zvi hodnotu thread_cache_size (to vak nespsob iadnu citen zmenu ak mte vlkna dobre implementovan).';
$strShowStatusThreads_runningDescr = 'Poet aktvnych (nespiacich) vlkien.';
$strShowTableDimension = 'Zobrazi rozmery tabuliek';
$strShowTables = 'Zobrazi tabuky';
$strShowThisQuery = ' Zobrazi tento dopyt znovu ';
$strShow = 'Ukza';
$strSimplifiedChinese = 'Zjednoduen ntina';
$strSingly = '(po jednom)';
$strSize = 'Vekos';
$strSkipQueries = 'Poet zznamov (prkazov), ktor sa maj zo zaiatku preskoi';
$strSlovak = 'Slovenina';
$strSlovenian = 'Slovinina';
$strSocketProblem = '(alebo soket loklneho MySQL servra nie je sprvne nastaven)';
$strSortByKey = 'Zoradi poda ka';
$strSorting = 'Zoraovanie';
$strSort = 'Triedi';
$strSpaceUsage = 'Zabran miesto';
$strSpanish = 'panielsky';
$strSplitWordsWithSpace = 'Slov s rozdelen medzerou (" ").';
$strSQLCompatibility = 'Reim kompatibility SQL';
$strSQLExportType = 'Typ vytvorench dopytov';
$strSQLImportOptions = 'Nastavenia SQL importu';
$strSQLOptions = 'Nastavenia pre SQL';
$strSQLParserBugMessage = 'Je mon, e ste nali chybu v SQL syntaktickom analyztore. Preskmajte podrobne SQL dopyt, predovetkm sprvnos umiestnenia vodzoviek. alia monos je, e nahrvate sbor s binrnymi dtami nezapsanmi v vodzovkch. Mete tie vyska poui prkazov riadok MySQL na odstrnenie problmu. Pokial stle mte problmy alebo syntaktick analyztor SQL stle hlsi chybu v dopyte, ktor v prkazovom riadku funguje, prosm pokste sa zredukova dopyt na o najmen, v ktorom sa problm ete vyskytuje a ohlste chybu na strnke phpMyAdmina spolu so sekciou VPIS uveden niie:';
$strSQLParserUserError = 'Vyskytla sa chyba v SQL dopyte. Niie uveden MySQL vstup (ak je nejak) Vm me pomc odstrni problm';
$strSQLQuery = 'SQL dopyt';
$strSQLResult = 'vsledok SQL';
$strSQL = 'SQL';
$strSQPBugInvalidIdentifer = 'Neplatn identifiktor';
$strSQPBugUnclosedQuote = 'Neuzatvoren vodzovky';
$strSQPBugUnknownPunctuation = 'Neznmy interpunkn reazec';
$strStatCheckTime = 'Posledn kontrola';
$strStatCreateTime = 'Vytvorenie';
$strStatement = 'daj';
$strStatisticsOverrun = 'Na vyaenom serveri me djs k preteeniu potadiel, take tatistiky servera mu by nepresn.';
$strStatUpdateTime = 'Posledn zmena';
$strStatus = 'Stav';
$strStorageEngines = 'lon Systmy';
$strStorageEngine = 'lon Systm';
$strStrucCSV = 'CSV dta';
$strStrucData = 'truktru a dta';
$strStrucExcelCSV = 'CSV pre MS Excel dta';
$strStrucNativeExcel = 'Natvne dta MS Excel';
$strStrucNativeExcelOptions = 'Nastavenia pre natvny Excel';
$strStrucOnly = 'Iba truktru';
$strStructPropose = 'Navrhn truktru tabuky';
$strStructure = 'truktra';
$strSubmit = 'Odoli';
$strSuccess = 'SQL dopyt bol spene vykonan';
$strSum = 'Celkom';
$strSwedish = 'vdsky';
$strSwitchToDatabase = 'Prepn na skoprovan databzu';
$strSwitchToTable = 'Prepn na skoprovan tabuku';

$strTableAlreadyExists = 'Tabuka %s u existuje!';
$strTableComments = 'Komentr k tabuke';
$strTableEmpty = 'Tabuka je przdna!';
$strTableHasBeenDropped = 'Tabuka %s bola odstrnen';
$strTableHasBeenEmptied = 'Tabuka %s bola vyprzden';
$strTableHasBeenFlushed = 'Tabuka %s bola vyprzdnen';
$strTableMaintenance = 'drba tabuky';
$strTableOfContents = 'Obsah';
$strTableOptions = 'Parametre tabuky';
$strTables = '%s tabuka(y)';
$strTableStructure = 'truktra tabuky pre tabuku';
$strTable = 'Tabuka';
$strTakeIt = 'zvoli';
$strTblPrivileges = 'Oprvnenia pre jednotliv tabuky';
$strTempData = 'Doasn dta';
$strTextAreaLength = ' Toto mono nepjde upravi,<br /> kvli svojej dke ';
$strThai = 'Thajina';
$strThemeDefaultNotFound = 'Predvolen vzhad %s nebol njden!';
$strThemeNoPreviewAvailable = 'Nhad nie je dostupn.';
$strThemeNotFound = 'Vzhad %s nebol njden!';
$strThemeNoValidImgPath = 'Nebola njden platn cesta k obrzkom pre vzhad %s!';
$strThemePathNotFound = 'Nebola njden platn cesta ku vzhadu %s!';
$strTheme = 'Vzhad';
$strThisHost = 'Tento pota';
$strThisNotDirectory = 'Nebol zadan adresr';
$strThreads = 'Poet vlkien';
$strThreadSuccessfullyKilled = 'Vlkno %s bol spene zabit.';
$strTime = 'as';
$strTimeoutInfo = 'Predchdzajcemu importu vypral asov limit. Po znovuodoslan formulra sa bude pokraova od pozcie %d.';
$strTimeoutNothingParsed = 'Avak pri poslednom pokuse neboli prijat iadne dta, o obvykle znamen, e phpMyAdmin nebude schopn dokoni tento import, pokia nebude zven asov limit behu skriptu v php.';
$strTimeoutPassed = 'asov limit behu skriptu vypral. Ak chcete import sboru dokoni, odolite znova formulr a import bude pokraova.';
$strToggleScratchboard = 'zobrazi grafick nvrh';
$strTotal = 'celkovo';
$strTotalUC = 'Celkom';
$strTraditionalChinese = 'Tradin ntina';
$strTraditionalSpanish = 'Tradin panielina';
$strTraffic = 'Prevdzka';
$strTransactionCoordinator = 'Koordintor transakci';
$strTransformation_application_octetstream__download = 'Zobraz odkaz na stiahnutie dt. Prv parameter je meno sboru, druh je meno stpca v tabuke obsahujci meno sboru. Ak zadte druh parameter, prv mus by przdny.';
$strTransformation_application_octetstream__hex = 'Zobraz dta v ich hexadecimlnej forme. Nepovinn parameter uruje po koko znakoch je vkladan medzera (tandardne po dvoch).';
$strTransformation_image_jpeg__inline = 'Zobraz nhad obrzku s odkazom na obrzok; parametre rka a vka v bodoch (pomer strn obrzku zostane zachovan)';
$strTransformation_image_jpeg__link = 'Zobraz odkaz na obrzok (napr. stiahnutie poa blob).';
$strTransformation_image_png__inline = 'Zobraz image/jpeg: inline';
$strTransformation_text_plain__dateformat = 'Zobraz dtum alebo as (TIME, TIMESTAMP alebo DATETIME) poda miestneho nastavenia. Prv parameter je posun (v hodinch), ktor bude pridan k zadanmu asu (predvolen je 0). Druh parameter je formtovac reazec pre php funkciu strftime().';
$strTransformation_text_plain__external = 'PLAT IBA PRE LINUX: Spust extern aplikciu, na jej tandardn vstup pole pole a zobraz vstup programu. Predvolen program je Tidy, ktor pekne sformtuje HTML. Z bezpenostnch dvodov muste rune upravi obsah sboru libraries/transformations/text_plain__external.inc.php a prida do neho povolen aplikcie. Prv parameter je slo aplikcie, ktor chcete poui a druh parametre s parametre tejto aplikcie. Ak je tret parameter nastaven na 1, vstup bude skonvertovan funkciou htmlspecialchars() (predvolen je 1). tvrt parameter v prpade, e je nastaven na 1 prid k vstupnmu textu parameter NOWRAP, m zabezpe zachovanie formtovania (predvolen je 1)';
$strTransformation_text_plain__formatted = 'Zachov pvodn formtovanie poa tak ako je uloen v databze.';
$strTransformation_text_plain__imagelink = 'Zobraz obrzok a odkaz z poa obsahujceho odkaz na obrzok. Prv parameter je prefix URL (napr. "http://domena.sk/"), druh a tret parameter uruj rku a vku obrzku.';
$strTransformation_text_plain__link = 'Zobraz odkaz z poa obsahujceho odkaz. Prv parameter je prefix URL (napr. "http://domena.sk/"), druh parameter je text odkazu.';
$strTransformation_text_plain__sql = 'Formtuje text ako SQL prkaz pomocou syntaxovho zvrazovania.';
$strTransformation_text_plain__substr = 'Zobraz iba as reazca. Prv parameter je posun od zaiatku (predvolen je 0) a druh uruje dku textu, ktor sa ma zobrazi, ak nie je zadan bude zobrazen zvyok textu. Tret parameter uruje znaky, ktor bud pridan na koniec skrtenho textu (predvolen je ...).';
$strTruncateQueries = 'Zobrazi skrtene dopyty';
$strTurkish = 'Turecky';
$strType = 'Typ';

$strUkrainian = 'Ukrajinsky';
$strUncheckAll = 'Odznai vetko';
$strUnicode = 'Unicode';
$strUnique = 'Uniktny';
$strUnknown = 'neznmy';
$strUnselectAll = 'Odznai vetko';
$strUnsupportedCompressionDetected = 'Poksili ste sa nata sbor s nepodporovanou kompresiou (%s). Bu nie je zahrnut podpora tejto kompresie alebo bola deaktivovan v konfigurcii.';
$strUpdatePrivMessage = 'Boli aktualizovan oprvnenia pre %s.';
$strUpdateProfileMessage = 'Profil bol aktualizovan.';
$strUpdateQuery = 'Aktualizova dopyt';
$strUpdComTab = 'Prosm pretajte si dokumentciu ako aktualizova tabuku s informciami o stpcoch (Column_comments Table)';
$strUpgrade = 'Mali by ste aktualizova %s na verziu %s alebo vyiu.';
$strUploadLimit = 'Pravdepodobne ste sa poksili uploadnu prli vek sbor. Pretajte si prosm %sdokumentciu%s, ako sa d toto obmedzenie obs.';
$strUploadsNotAllowed = 'Ukladanie sborov na server nie je povolen.';
$strUsage = 'Vyuitie';
$strUseBackquotes = ' Poui opan apostrof pri nzvoch tabuliek a pol ';
$strUsedPhpExtensions = 'Pouit rozrenia PHP';
$strUseHostTable = 'Poui tabuku s hostitemi';
$strUserAlreadyExists = 'Pouvate %s u existuje!';
$strUserEmpty = 'Meno pouvatea je przdne!';
$strUserName = 'Meno pouvatea';
$strUserNotFound = 'Zvolen pouvate nebol njden v tabuke prv.';
$strUserOverview = 'Prehad pouvatelov';
$strUser = 'Pouvate';
$strUsersDeleted = 'Vybran pouvatelia bol spene odstrnen.';
$strUsersHavingAccessToDb = 'Pouvatelia majci prstup k &quot;%s&quot;';
$strUseTabKey = 'Pre pohyb medzi hodnotami pouite klvesu TAB alebo pre pohyb vetkmi smermi klvesy CTRL+pky';
$strUseTables = 'Poui tabuky';
$strUseTextField = 'Poi textov pole';
$strUseThisValue = 'Poui tto hodnotu';

$strValidateSQL = 'Potvrdi platnos SQL';
$strValidatorError = 'SQL validator nemohol by inicializovan. Prosm skontrolujte, i s naintalovan vetky potrebn rozrenia php, tak ako s popsan v %sdocumentation%s.';
$strValue = 'Hodnota';
$strVar = 'Premenn';
$strVersionInformation = 'Informcie o verzii';
$strViewDumpDatabases = 'Export databz';
$strViewDumpDB = 'Zobrazi dump (schmu) databzy';
$strViewDump = 'Zobrazi dump (schmu) tabuky';
$strViewHasBeenDropped = 'Pohad %s bol odstrnen';
$strViewMaxExactCount = 'Tento pohad obsahuje viac ako %s riadkov. Vi %sdokumentcia%s.';
$strView = 'Pohad';

$strWebServerUploadDirectoryError = 'Adresr uren pre upload sborov sa ned otvori';
$strWebServerUploadDirectory = 'upload adresr web serveru';
$strWelcome = 'Vitajte v %s';
$strWestEuropean = 'Zpadn Eurpa';
$strWildcard = 'nahradzujci znak';
$strWindowNotFound = 'Cieov okno prehliadaa nemohlo by aktualizovan. Mono ste zatvorili rodiovsk okno, alebo prehliada blokuje opercie medzi oknami z dvodu bezpenostnch nastaven';
$strWithChecked = 'Vber:';
$strWriteRequests = 'Poiadavkov na zpis';
$strWritingCommentNotPossible = 'Komentr sa ned zapsa';
$strWritingRelationNotPossible = 'Vzah sa ned zapsa';
$strWrongUser = 'Zl pouvatesk meno alebo heslo. Prstup zamietnut.';

$strXMLOptions = 'Nastavenia pre XML';
$strXML = 'XML';

$strYes = 'no';

$strZeroRemovesTheLimit = 'Poznmka: Nastavenie tchto parametrov na 0 (nulu) odstrni obmedzenia.';
$strZip = '"zozipovan"';

// To translate:

$strPDFReportExplanation = '(Generates a report containing the data of a single table)';  //to translate

$strFontSize = 'Font size';  //to translate
$strLanguage = 'Language';  //to translate
?>
